function xReturn = getAphiaChildrenByID(obj,AphiaID,offset,marine_only)
%getAphiaChildrenByID(obj,AphiaID,offset,marine_only)
%
%   <strong>Get the direct children (max. 50) for a given AphiaID</strong>
%   		<br />Parameters:
%   		<ul>
%   			<li><u>offset</u>: Starting recordnumber, when retrieving next chunk of (50) records. Default=1</li>
%   			<li><u>marine_only</u>: Limit to marine taxa. Default=true</li>
%   		</ul>
%   
%     Input:
%       AphiaID = (int)
%       offset = (int)
%       marine_only = (boolean)
%   
%     Output:
%       return{:} = (AphiaRecord)

% Build up the argument lists.
values = { ...
   AphiaID, ...
   offset, ...
   marine_only, ...
   };
names = { ...
   'AphiaID', ...
   'offset', ...
   'marine_only', ...
   };
types = { ...
   '{http://www.w3.org/2001/XMLSchema}int', ...
   '{http://www.w3.org/2001/XMLSchema}int', ...
   '{http://www.w3.org/2001/XMLSchema}boolean', ...
   };

% Create the message, make the call, and convert the response into a variable.
soapMessage = createSoapMessage( ...
    'http://aphia/v1.0/AphiaRecords', ...
    'getAphiaChildrenByID', ...
    values,names,types,'rpc');
response = callSoapService( ...
    obj.endpoint, ...
    'getAphiaChildrenByID', ...
    soapMessage);
xReturn = parseSoapResponse(response);
