function xReturn = getAphiaRecordsByVernacular(obj,vernacular,like,offset)
%getAphiaRecordsByVernacular(obj,vernacular,like,offset)
%
%   <strong>Get one or more Aphia Records (max. 50) for a given vernacular</strong>
%   		<br />Parameters:
%   		<ul>
%   			<li><u>like</u>: Add a '%'-sign before and after the input (SQL LIKE '%vernacular%' function). Default=false</li>
%   			<li><u>offset</u>: Starting recordnumber, when retrieving next chunk of (50) records. Default=1</li>
%   		</ul>
%   		<br /> For the structure of the returned AphiaRecords, please refer to the function getAphiaRecordByID()
%   
%     Input:
%       vernacular = (string)
%       like = (boolean)
%       offset = (int)
%   
%     Output:
%       return{:} = (AphiaRecord)

% Build up the argument lists.
values = { ...
   vernacular, ...
   like, ...
   offset, ...
   };
names = { ...
   'vernacular', ...
   'like', ...
   'offset', ...
   };
types = { ...
   '{http://www.w3.org/2001/XMLSchema}string', ...
   '{http://www.w3.org/2001/XMLSchema}boolean', ...
   '{http://www.w3.org/2001/XMLSchema}int', ...
   };

% Create the message, make the call, and convert the response into a variable.
soapMessage = createSoapMessage( ...
    'http://aphia/v1.0/AphiaRecords', ...
    'getAphiaRecordsByVernacular', ...
    values,names,types,'rpc');
response = callSoapService( ...
    obj.endpoint, ...
    'getAphiaRecordsByVernacular', ...
    soapMessage);
xReturn = parseSoapResponse(response);
